OME, Go (omego)
===============

.. image:: https://travis-ci.org/ome/omego.png
   :target: http://travis-ci.org/ome/omego

.. image:: https://badge.fury.io/py/omego.svg
    :target: https://badge.fury.io/py/omego

The omego command provides utilities for installing and managing OME applications.

Getting Started
---------------

For Python 2.6, you will need to install `argparse`_

::

    $ pip install argparse

With that, it's possible to execute omego:

::

    $ python omego/main.py

Pip installation
-----------------

To install the latest release of omego use pip install:

::

    $ pip install omego
    $ omego

License
-------

omego is released under the GPL.

Copyright
---------

2013-2016, The Open Microscopy Environment

.. _argparse: http://pypi.python.org/pypi/argparse
